/****************************************************************
*	TITLE               :   BMS                                 *
*   APPLICATION DOMAIN  :   Bank Management System              *
*   VERSION             :   1.0                                 *
*   DEVELOPER           :	Mr. Abdel Raouf Yessoufou           *
*	SYSTEM ANALIST      :   Mr. Abdel Raouf Yessoufou           *
*	SYSTEM DESIGNER     :	Mr. Abdel Raouf Yessoufou           *
*	DATABASE DESIGNER   :	Mr. Abdel Raouf Yessoufou           *
*   YEAR CREATED        :   2008                                *
*   NOTES               :   This is just the begining.          *
*                           The best is yet to come as          *
*                           I am looking forward to adding      *
*                           more features for next version      *
*****************************************************************/

using System;
using System.Windows.Forms;
using System.IO;
using System.Drawing;

using BMS.CLASSES;

namespace BMS.FORMS
{
    public partial class frm_BANK_PROFILE : Form
    {
        int intBankID = 0;
        cls_BANK_PROFILE cls_BANK_PROFILE_obj = new cls_BANK_PROFILE();
        bool blAdd = false;
        bool blEdit = false;

        string strPictureSource;
        string strPictureExtension;
        string strPictureName;
        string strOldPictureName;

        public frm_BANK_PROFILE()
        {
            InitializeComponent();
        }

        private void frm_BANK_PROFILE_Load(object sender, EventArgs e)
        {
            picLogo.Image = null;
            disableCtl();
            loadBankProfile();
            cls_UTILITY.disableFields(grpBoxDetails);
        }

        private void btnClose_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void loadBankProfile()
        {
            cls_BANK_PROFILE_obj.loadBankProfile();

            intBankID = cls_BANK_PROFILE_obj.IntBankID;
            txtBankName.Text = cls_BANK_PROFILE_obj.StrBankName;
            txtMotto.Text = cls_BANK_PROFILE_obj.StrMotto;
            txtSlogan.Text = cls_BANK_PROFILE_obj.StrSlogan;
            if (cls_BANK_PROFILE_obj.StrPicture == null) 
            {
                picLogo.Image = Image.FromFile(cls_GLOBAL_VARIABLES.strPictureDestination + @"\NoLogo.bmp"); 
            }
            else 
            { 
                picLogo.Image = Image.FromFile(cls_GLOBAL_VARIABLES.strPictureDestination + @"\" + cls_BANK_PROFILE_obj.StrPicture);
                strOldPictureName = cls_BANK_PROFILE_obj.StrPicture;
            }
            if (txtBankName.Text.Trim() != string.Empty) 
            { btnAddNew.Enabled = false; }
        }

        private void disableCtl()
        {
            //btnAddNew.Enabled = true;
            btnEdit.Enabled = true;
            btnDelete.Enabled = true;
            btnClose.Enabled = true;

            btnCancel.Enabled = false;
            btnSave.Enabled = false;
            btnBrowseLogo.Enabled = false;
            btnRemoveLogo.Enabled = false;

        }

        private void enableCtl()
        {
           // btnAddNew.Enabled = false;
            btnEdit.Enabled = false;
            btnDelete.Enabled = false;
            btnClose.Enabled = false;

            btnCancel.Enabled = true;
            btnSave.Enabled = true;
            btnBrowseLogo.Enabled = true ;
            btnRemoveLogo.Enabled = true ;
        }

        private void btnAddNew_Click(object sender, EventArgs e)
        {
            blAdd = true;
            blEdit = false;
            cls_UTILITY.ClearFields(grpBoxDetails);
            enableCtl();
            cls_UTILITY.enableFields(grpBoxDetails);
        }

        private void btnEdit_Click(object sender, EventArgs e)
        {
            if (intBankID == 0 || txtBankName.Text.Trim() == string.Empty) { cls_UTILITY.displayMessage("Please select the currency type to edit", MessageBoxIcon.Exclamation); return; }
            blEdit = true;
            blAdd = false;
            enableCtl();
            cls_UTILITY.enableFields(grpBoxDetails);
        }

        private void btnCancel_Click(object sender, EventArgs e)
        {
            disableCtl();
            cls_UTILITY.disableFields(grpBoxDetails);
            cls_UTILITY.ClearFields(grpBoxDetails);
        }

        private void btnSave_Click(object sender, EventArgs e)
        {
            if (cls_UTILITY.checkEmptyTextBox(txtBankName, "Please enter the bank name") == false) { disableCtl(); }
            if (cls_UTILITY.checkImage (picLogo , "Please select the bank logo") == false) { disableCtl(); }

            cls_BANK_PROFILE_obj.StrBankName = txtBankName.Text.Trim();
            cls_BANK_PROFILE_obj.StrMotto = txtMotto.Text.Trim();
            cls_BANK_PROFILE_obj.StrSlogan = txtSlogan.Text.Trim();
            if (strPictureName == null || strPictureName == "")
            {
                cls_BANK_PROFILE_obj.StrPicture = "NoLogo.bmp";
            }
            else
            {
                cls_BANK_PROFILE_obj.StrPicture = strPictureName;
                cls_UTILITY.CopyImage(strPictureSource, cls_GLOBAL_VARIABLES.strPictureDestination, strPictureName.ToString());
            }


            if (blAdd == true && blEdit == false)
            {
                if (cls_BANK_PROFILE_obj.saveBankProfile() != 1)
                { cls_UTILITY.displayMessage("An error occured while saving data. Please retry", MessageBoxIcon.Error); }
                else
                {
                    cls_UTILITY.displayMessage("Details saved successfully", MessageBoxIcon.Information);
                    cls_BANK_PROFILE_obj.loadBankProfile();
                    cls_UTILITY.disableFields(grpBoxDetails);
                }
            }
            else if (blAdd == false && blEdit == true)
            {
                if (cls_BANK_PROFILE_obj.updateBankProfile(intBankID) != 1)
                { cls_UTILITY.displayMessage("An error occured while updating data. Please retry", MessageBoxIcon.Error); }
                else
                {
                    cls_UTILITY.displayMessage("Details updated successfully", MessageBoxIcon.Information);
                    cls_BANK_PROFILE_obj.loadBankProfile();
                    cls_UTILITY.disableFields(grpBoxDetails);
                }
            }

        }

        private void btnDelete_Click(object sender, EventArgs e)
        {
            if (intBankID == 0 || txtBankName.Text.Trim() == string.Empty) { cls_UTILITY.displayMessage("Please select the currency type to delete", MessageBoxIcon.Exclamation); return; }
            cls_UTILITY.displayMessage("Unable to delete the bank profile. It might be referenced somewhere else.", MessageBoxIcon.Error);
        }

        private void btnBrowseLogo_Click(object sender, EventArgs e)
        {
            OpenFileDialog openFileDialog = new OpenFileDialog();

            openFileDialog.InitialDirectory = "C:/";
            openFileDialog.Filter = "All Files|*.*|Bitmaps|*.bmp|GIFs|*.gif|JPEGs|*.jpg";
            openFileDialog.FilterIndex = 2;

            if (openFileDialog.ShowDialog() == DialogResult.OK)
            {
                picLogo.Image = Image.FromFile(openFileDialog.FileName);
                picLogo.SizeMode = PictureBoxSizeMode.StretchImage;
                picLogo.BorderStyle = BorderStyle.Fixed3D;
                strPictureSource = openFileDialog.FileName;
                string[] strPicturename = strPictureSource.Split('\\');
                strPictureName = strPicturename[strPicturename.Length - 1].ToString();
                strPictureExtension = new FileInfo(openFileDialog.FileName).Extension;
            }
        }

        private void btnRemoveLogo_Click(object sender, EventArgs e)
        {
            if (cls_UTILITY.displayMessage("Are you sure you want to remove bank logo?") == true)
            {
                if (cls_BANK_PROFILE_obj.updateBankLogo() > 0)
                {
                    //cls_UTILITY.DeleteImage(cls_GLOBAL_VARIABLES.strPictureDestination, strOldPictureName);
                }
            }
        }

    }
}